#
# spec file for package quazip
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global quazip_flavor qt5%{nil}
%if "%{quazip_flavor}" == ""
ExclusiveArch:  do_not_build
%endif
%define no_pkgconfig 0
%if "%{quazip_flavor}" == "qt6"
%define qt6 1
%define pkg_suffix -qt6
# No pkgconfig file before 6.3.1
%if %{pkg_vcmp cmake(Qt6Core) <= 6.3.0}
%define no_pkgconfig 1
%endif
%endif
%if "%{quazip_flavor}" == "qt5"
%define qt5 1
%define pkg_suffix -qt5
%endif
%define so_ver 1
%define lib_ver 1_4_0
Name:           quazip%{?pkg_suffix}
Version:        1.4
Release:        2.8
Summary:        C++ wrapper for ZIP/UNZIP
License:        GPL-2.0-or-later OR LGPL-2.1-or-later
URL:            https://github.com/stachenov/quazip
Source:         https://github.com/stachenov/quazip/archive/v%{version}.tar.gz#/quazip-%{version}.tar.gz
BuildRequires:  cmake >= 3.15
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(zlib)
%if 0%{?qt5}
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Test)
%endif
%if 0%{?qt6}
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Test)
%endif

%description
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt toolkit.
Useful to access ZIP archives from Qt programs.

%package -n libquazip%{so_ver}-%{quazip_flavor}-%{lib_ver}
Summary:        C++ wrapper for ZIP/UNZIP
%if 0%{?qt5}
Provides:       libquazip%{so_ver} = %{version}
Obsoletes:      libquazip%{so_ver} < %{version}
Provides:       libquazip5-%{so_ver} = %{version}
Obsoletes:      libquazip5-%{so_ver} < %{version}
%endif

%description -n libquazip%{so_ver}-%{quazip_flavor}-%{lib_ver}
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt toolkit.
Useful to access ZIP archives from Qt programs.

%package        devel
Summary:        Development files for %{name}
Requires:       libquazip%{so_ver}-%{quazip_flavor}-%{lib_ver} = %{version}
Requires:       pkgconfig(bzip2)
Requires:       pkgconfig(zlib)
%if 0%{?qt5}
Requires:       cmake(Qt5Core)
Provides:       libquazip-qt5-devel = %{version}
Obsoletes:      libquazip-qt5-devel < %{version}
Provides:       quazip-devel = %{version}
Obsoletes:      quazip-devel < %{version}
%endif
%if 0%{?qt6}
Requires:       cmake(Qt6Core)
Requires:       cmake(Qt6Core5Compat)
%endif

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use quazip.

# Only build the doc package once
%if 0%{?qt5}
%package -n quazip-doc
Summary:        Documentation for quazip, a C++ wrapper for ZIP/UNZIP
Provides:       libquazip-qt5-doc = %{version}
Obsoletes:      libquazip-qt5-doc < %{version}
Provides:       quazip-qt5-doc = %{version}
Obsoletes:      quazip-qt5-doc < %{version}
BuildArch:      noarch

%description -n quazip-doc
A C++ wrapper for the Gilles Vollant's ZIP/UNZIP C package, using Qt toolkit.
Useful to access ZIP archives from Qt programs.

This package contains documentation for quazip.
%endif

%prep
%autosetup -p1 -n quazip-%{version}

%build
%if 0%{?qt6}
%cmake_qt6
%qt6_build
%endif
%if 0%{?qt5}
%cmake
%cmake_build
cd ..
sed -i 's/HTML_TIMESTAMP\s*= YES/HTML_TIMESTAMP=NO/' Doxyfile
doxygen -u
doxygen
%endif

%install
%if 0%{?qt6}
%qt6_install
%endif
%if 0%{?qt5}
%cmake_install

# install docs
mkdir -pv %{buildroot}%{_defaultdocdir}/quazip-doc
cp -r doc/html %{buildroot}%{_defaultdocdir}/quazip-doc/
%fdupes -s %{buildroot}%{_defaultdocdir}/quazip-doc
%endif

%if %{no_pkgconfig}
rm %{buildroot}%{_libdir}/pkgconfig/quazip%{so_ver}-qt6.pc
%endif

%post -n libquazip%{so_ver}-%{quazip_flavor}-%{lib_ver} -p /sbin/ldconfig
%postun -n libquazip%{so_ver}-%{quazip_flavor}-%{lib_ver} -p /sbin/ldconfig

%files -n libquazip%{so_ver}-%{quazip_flavor}-%{lib_ver}
%license COPYING*
%doc NEWS.txt README*
%{_libdir}/libquazip%{so_ver}-%{quazip_flavor}.so.%{so_ver}*

%files devel
%license COPYING*
%doc QuaZip-1.x-migration.md
%if 0%{?qt5}
%{_includedir}/QuaZip-Qt5-%{version}
%{_libdir}/cmake/QuaZip-Qt5-%{version}
%endif
%if 0%{?qt6}
%{_includedir}/QuaZip-Qt6-%{version}
%{_libdir}/cmake/QuaZip-Qt6-%{version}
%endif
%{_libdir}/libquazip%{so_ver}-%{quazip_flavor}.so
%if !%{no_pkgconfig}
%{_libdir}/pkgconfig/quazip%{so_ver}-%{quazip_flavor}.pc
%endif

%if 0%{?qt5}
%files -n quazip-doc
%doc %{_defaultdocdir}/quazip-doc
%endif

%changelog
* Tue Jan 24 2023 Christophe Marin <christophe@krop.fr>
- Make sure the bzip2 and zlib devel packages are pulled when
  installing quazip's devel package
* Mon Jan 23 2023 Christophe Marin <christophe@krop.fr>
- Update to 1.4.0
  * bzip2 compression support added
* Tue Jun 21 2022 Christophe Giboudeaux <christophe@krop.fr>
- Install the pkgconfig file when building against Qt 6.3.1
* Sun Apr 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.3
  * All JlCompress methods are now public
  * Default Qt major version is now detected automatically
  * Minor CMake and pkg-config fixes and improvements
- Add a Qt6 flavor
* Sat Nov 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.2
  * Add CMake option to disable installation
  * Qt's internal zlib can be used now (QUAZIP_USE_QT_ZLIB, OFF
    by default)
  * Make tests optional (QUAZIP_ENABLE_TESTS, OFF by default)
  * Fix: QuaZip::close() can be safely called multiple times now
  * Fix: -lz added to pkgconfig
- Fix -devel package runtime requirement
* Sun Oct 11 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1
  * Fixed Unix symlink handling in JlCompress compression
  * Implemented Unix symlink handling in JlCompress extraction
  * Added 1.x migration guide
- Removed compatibility symlink (it was pointless anyway)
* Mon Oct  5 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0
  * Preliminary Qt 6 support
  * Consistent naming of binaries (libquazip1-qt5 style)
  * Modern CMake support
  * Ditched qmake support
- Drop quazip-0.9-pkgconfig.patch and
  quazip-0.9-no_static_library.patch (no longer necessary)
* Sun May 24 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.1
  * A very minor release, adds just a couple of version variables
    for CMake.
* Fri May  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9
  * Support for extended timestamps
  * Various contributed CMake fixes
- Drop quazip-0.8.1_pkgconfig.patch (merged upstream)
- Add quazip-0.9-pkgconfig.patch
- Add quazip-0.9-no_static_library.patch
- Drop Group tag
* Tue Jun  4 2019 Luigi Baldoni <aloisio@gmx.com>
- Added quazip-0.8.1_pkgconfig.patch to produce a .pc file when
  building with cmake
* Sun Jun  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.1
  * A bugfix release. Fixes a regression in CMake.
  version 0.8
  * Support for UTF-8 in file names and comments
    (Denis Zavorotnyy)
  * get/setOsCode(), get/setDefaultOsCode()
  * Fixed Z_STREAM_END handling in QuaZioDevice
* Fri Apr  5 2019 Jan Engelhardt <jengelh@inai.de>
- Fix description grammar.
* Thu Apr  4 2019 Christophe Giboudeaux <christophe@krop.fr>
- Drop the Qt4-based quazip.
- Rename quazip-qt5 to quazip.
- Merge the changelog files.
* Sat Jan 26 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Use %%license
- Clean spec files
- Project moved to GitHub
- Update to 0.7.6:
  * Fixed the Zip Slip vulnerability in JlCompress
  * Renamed crypt.h to minizip_crypt.h to avoid conflicts
- Update to 0.7.5:
  * Fixed a migration artifact (additional subdirectory in the tarball)
  * Fixed target_link_libraries call in CMakeLists
  * Worked around a Qt 4.6 bug (QTBUG-15421) screwing up hidden
    files handling in JlCompress::compressDir()
  * Removed Q_FOREACH uses to avoid conflicts (SF patch #32)
- Update to 0.7.4:
  * Static analysis patch from Intel Deutschland GmbH
  * Replaced UNUSED with QUAZIP_UNUSED to avoid name clashes
  * Minor bug fixes
* Tue May 30 2017 christophe@krop.fr
- Update to 0.7.3
  * Symlink handling.
  * Static linking exception for LGPL.
  * Minor bug fixes.
  * New JlCompress methods (QIODevice*-based API by Lukasz Kwiecinski)
  * Implemented QuaZioDevice::atEnd() and bytesAvailable(). these
    might break ABI, but pretty unlikely.
- Drop quazip-0.7.1-r260.diff. Merged upstream
* Tue Nov 10 2015 mlin@suse.com
- Add Provides/Obsoletes for old libquazip-qt5
* Wed Nov  4 2015 hpj@urpla.net
- streamline quazip and libquazip-qt5 specs
- rename libquazip-qt5.* to quazip-qt5.*
- apply quazip-0.7.1-r260.diff generated from svn
  svn diff -r r250:r260
* Thu May  7 2015 hrvoje.senjan@gmail.com
- Comment out the Source URL, since we now have a git snapshot
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 0.7.1
  * Fixed licensing issues (bug #45).
  * Added the convenience method QuaZipFileInfo::isEncrypted().
- Changes from version 0.7
  * It is now possible to write ZIP files to sequential devices like
    sockets (only in mdCreate mode, so no self-extract, sorry).
  * A few zip64 fixes.
  * Several bug fixes and portability improvements.
- Changes from version 0.6.2
  * QuaZipNewInfo / QuaZipFileInfo64 now provide API to access/set
    NTFS time stamps - useful even on non-NTFS systems if you
    need more precise dates and times than default ones.
  * QuaZipNewInfo may now be initialized from QuaZipFileInfo64.
  * No more crashes when using QSaveFile as QIODevice for ZIP.
  * The new QuaZip::setAutoClose() method allows to leave the
    QIODevice open when you close the QuaZip instance.
  * qztest now depends on quazip, no longer breaking the build.
- Changes from version 0.6.1
  * Improved zip64 support.
  * A LOT more tests thanks to g++ --coverage / lcov.
  * JlCompress extraction methods now create files with default
    permissions if they are zero in the original archive.
  * Some QuaZipDir fixes (thanks to the new tests).
- Changes from version 0.6
  * Minizip updated to 1.1 (with all the necessary modifications
    re-done), and that means that...
  * the long-awaited zip64 support is now available!
  * A few rather minor fixes.
- Changes from version 0.5.2
  * Some minor bug fixes.
  * API to access file permissions subfield of the external
    attributes.
  * MS VS 2012 Express support.
  * API to set the default codec used to encode/decode file names
    (mainly for use by various wrappers such as JlCompress, when
    you don't have direct access to the underlying QuaZip instance).
* Fri Feb  6 2015 dev@dominik-schmidt.de
- update to latest svn trunk
  * fixes coninstallation of Qt4 and Qt5 devel packages
  * remove patch soversion.diff, it was a downstream hack
  * upstream uses a new soname now
* Sun Dec 28 2014 alinm.elena@gmail.com
- this is qt5 version splitted from the qt4 one.
* Sat Oct 11 2014 crrodriguez@opensuse.org
- quazip-devel should require pkgconfig(qtcore)
- Build shared library with -fvisibility-inlines-hidden
- Ensure doxygen does not create html files with timestamps.
* Sat Sep  7 2013 stefan@fam-elser.de
- Update to 0.5.1 version:
  * Lots of QuaZipDir fixes, thanks to all bug reporters.
  * Full Qt Creator support.
  * MS VS 2010 Express support.
  * Qt5 support (didn't need any source code changes anyway).
  * Lots of minor bug fixes.
* Sat Dec 15 2012 p.drouand@gmail.com
- Update to 0.5 version:
  * Added run_moc.bat files for building under Windows in case Qt
    integration is not available (e. g. VS 2008 Express).
  * Added the QuaZipDir class to simplify ZIP navigation in terms
    of directories.
  * Added the QuaGzipFile class for working with GZIP archives. It
    was added as a bonus since it has nothing to do with the main
    purpose of the library. It probably won't get any major
    improvements, although minor bug fixes are possible.
  * Added the QuaZIODevice class for working with zlib
    compression. It has nothing to do with the ZIP format, and
    therefore the same notice as for the QuaGzipFile applies.
  * The global comment is no longer erased when adding files to
    an archive.
  * Many bug fixes.
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Mon Sep 12 2011 adam@mizerski.pl
- update to 0.4.3
  See NEWS for details
* Wed Sep  7 2011 adam@mizerski.pl
- update to 0.4.2
  See NEWS for details
* Fri May 27 2011 cfarrell@novell.com
- license update: GPL-2.0+ or LGPL-2.1+
  Update license syntax. Also GPLv2 was not correct. It is an ^or later^
  clause
* Wed Feb 23 2011 adam@mizerski.pl
- new package
